==> configparsersimplifier-1.0.tar.gz: configparsersimplifier-1.0/configparsersimplifier/configparsersimplifier.py <==
from configparser import ConfigParser

class ConfigParserSimple:
    def __init__(self, config_path):
        self.cpath = config_path
        self.config = ConfigParser()
    
    def apply_changes(self):
        '''
        Записывает изменения в файл.
        '''
        with open(r'{}'.format(self.cpath), 'w') as config_file:
            self.config.write(config_file)
    
    def create_config(self, section: str, **pairs):
        '''
        Создает .ini файл.
        '''
        self.config.add_section(section)
        for k, v in pairs.items():
            self.config.set(section, k, v)
        
        self.apply_changes()
    
    def read_dict(self, settings: dict):
        '''
        Читает настройки из файла.
        '''
        self.config.read_dict(settings)
    
    def get_keys(self, section: str, keys: list):
        '''
        Возвращает список значений ключей
        '''
        values = list()
        self.config.read(self.cpath)
        for key in keys:
            values.append(f'{self.config.get(section, key)}')

        return values
    
    def get_sections(self):
        '''
        Возвращает список существующих секций.
        '''
        self.config.read(self.cpath)
        return self.config.sections()
    
    
    def set_keys(self, section: str, **pairs):
        '''
        Устанавливает значение ключам.
        '''
        self.config.read(self.cpath)
        for k, v in pairs.items():
            self.config.set(section, k, v)
        
        self.apply_changes()
    
    def delete_keys(self, section: str, keys: list):
        '''
        Удаляет ключи.
        '''
        self.config.read(self.cpath)
        for key in keys:
            self.config.remove_option(section, key)
    
    def delete_section(self, section: str):
        '''
        Удаляет секцию.
        '''
        self.config.read(self.cpath)
        self.config.remove_section(section)

==> configparsersimplifier-1.1.tar.gz: configparsersimplifier-1.1/configparsersimplifier/configparsersimplifier.py <==
from configparser import ConfigParser

class ConfigParserSimple:
    def __init__(self, config_path):
        self.cpath = r'{}'.format(config_path)
        self.config = ConfigParser()
    
    def add_section(self, section: str):
        '''
        Добавляет секцию в файл.
        '''
        self.config.add_section(section)
    
    def set_keys(self, section: str, **pairs):
        '''
        Позволяет записать в файл сразу несколько пар ключ=значение.
        '''
        for k, v in pairs.items():
            self.config.set(section, str(k), str(v))
        
        with open(self.cpath, 'w') as config_file:
            self.config.write(config_file)
    
    def get_keys(self, section: str, keys: list):
        '''
        Позволяет получить из файла сразу несколько пар ключ=значение.
        '''
        values = list()
        for key in keys:
            values.append(f'{self.config.get(section, key)}')

        return values
    
    def get_sections(self):
        '''
        Возвращает список существующих секций.
        '''
        return self.config.sections()
    
    def delete_keys(self, section: str, keys: list):
        '''
        Позволяет удалить из файла сразу несколько пар ключ=значение.
        '''
        for key in keys:
            self.config.remove_option(section, key)
        
        with open(self.cpath, 'w') as config_file:
            self.config.write(config_file)
    
    def delete_section(self, section: str):
        '''
        Удаляет секцию.
        '''
        self.config.remove_section(section)
        
        with open(self.cpath, 'w') as config_file:
            self.config.write(config_file)
